@@ -137,6 +137,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 			break;
 
 		default:
+			break;
 		}
 
 		if (full_uri)
@@ -455,6 +456,10 @@ path_list_new (const char  *text_uri,
 			str_uri = gnome_vfs_uri_to_string (full_uri, GNOME_VFS_URI_HIDE_NONE);
 			unesc_uri = gnome_vfs_unescape_string (str_uri, NULL);
 
+#ifdef DEBUG
+			g_print ("--> %s\n", unesc_uri);
+#endif
+
 			file_list = g_list_prepend (file_list, unesc_uri);
 			g_free (str_uri);
 			break;
@@ -988,15 +993,11 @@ get_unique_desktop_file (const char *base_dir)
 	static int n = 0;
 	
 	while (TRUE) {
-		char     *path;
-		char     *name;
+		char  *path;
+		char  *name;
 
-		name = g_strdup_printf ("QL.%d.%d", getpid (), n++);
-		path = g_strconcat (base_dir,
-				    "/",
-				    name,
-				    ".desktop",
-				    NULL);
+		name = g_strdup_printf ("QL.%d.%d.desktop", getpid (), n++);
+		path = g_build_filename (base_dir, name, NULL);
 		g_free (name);
 
 		if (! g_file_test (path, G_FILE_TEST_EXISTS))
@@ -1024,15 +1025,12 @@ is_desktop_file (const char *uri)
 
 	if (result != GNOME_VFS_OK) 
 		is_desktop = FALSE;
-	
-	if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE &&
-	    info->type == GNOME_VFS_FILE_TYPE_REGULAR &&
-	    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE &&
-	    strcmp (info->mime_type, "application/x-gnome-app-info") != 0) 
+	else if ((strcmp (info->mime_type, "application/x-gnome-app-info") != 0)
+		 && (strcmp (info->mime_type, "application/x-desktop") != 0)) 
 		is_desktop = FALSE;
-		
+	
 	gnome_vfs_file_info_unref (info);
-
+	
 	return is_desktop;
 }
 
